#include "project.h"
#include "stdio.h"
#include "i2c_utils.h"
#include "hs3001.h"

char str[128] ; /* print buffer */

void print(char *str)
{
    UART_UartPutString(str) ;
}

void splash(void)
{
    sprintf(str, "TSoC HS3001(I2C) Test (%s %s)\n", __DATE__, __TIME__) ;
    print(str) ;
}

void init_hardware(void) 
{
    CyGlobalIntEnable; /* Enable global interrupts. */

    UART_Start() ;
    I2C_Start() ;
}

int main(void)
{
    float humidity ;
    float temperature ;
    int status ;
    uint8_t data[4] ;
    
    init_hardware() ;
    
    splash() ;
    
    print("Temp(C),  Humidity(%)\n") ;
    for(;;)
    {
        HS3001_Measurement_Request() ;
        CyDelay(500) ;
        HS3001_Data_Fetch(data) ;

        status = (data[0] >> 6) & 0x03 ;
        if (status == 0) { /* valid data */
            humidity = 100.0 * (float)(((data[0] & 0x3F) << 8) | data[1])/16383.0 ;
            temperature = 165.0 * (float)((data[2] << 6) | (data[3] >> 2)) / 16383.0 - 40.0 ;
        
            sprintf(str, " %3d.%02d,  %3d.%02d\n",
                (int)(temperature + 0.005), (int)(100 * temperature + 0.5) % 100,
                (int)(humidity + 0.005), (int)(100 * humidity + 0.5) % 100) ;
            print(str) ;
        }
        CyDelay(1000) ;
    }
}

/* [] END OF FILE */
